/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * This code was generated by https://code.google.com/p/google-apis-client-generator/
 * (build: 2013-08-14 15:32:06 UTC)
 * on 2013-08-19 at 20:09:47 UTC 
 * Modify at your own risk.
 */

package com.google.api.services.gamesManagement;

/**
 * Service definition for GamesManagement (v1management).
 *
 * <p>
 * The Management API for Google Play Game Services.
 * </p>
 *
 * <p>
 * For more information about this service, see the
 * <a href="https://developers.google.com/games/services" target="_blank">API Documentation</a>
 * </p>
 *
 * <p>
 * This service uses {@link GamesManagementRequestInitializer} to initialize global parameters via its
 * {@link Builder}.
 * </p>
 *
 * @since 1.3
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public class GamesManagement extends com.google.api.client.googleapis.services.json.AbstractGoogleJsonClient {

  // Note: Leave this static initializer at the top of the file.
  static {
    com.google.api.client.util.Preconditions.checkState(
        com.google.api.client.googleapis.GoogleUtils.MAJOR_VERSION == 1 &&
        com.google.api.client.googleapis.GoogleUtils.MINOR_VERSION == 14,
        "You are currently running with version %s of google-api-client. " +
        "You need version 1.14 of google-api-client to run version " +
        "1.14.2-beta of the Google Play Game Services Management API library.", com.google.api.client.googleapis.GoogleUtils.VERSION);
  }

  /**
   * The default encoded root URL of the service. This is determined when the library is generated
   * and normally should not be changed.
   *
   * @since 1.7
   */
  public static final String DEFAULT_ROOT_URL = "https://www.googleapis.com/";

  /**
   * The default encoded service path of the service. This is determined when the library is
   * generated and normally should not be changed.
   *
   * @since 1.7
   */
  public static final String DEFAULT_SERVICE_PATH = "games/v1management/";

  /**
   * The default encoded base URL of the service. This is determined when the library is generated
   * and normally should not be changed.
   */
  public static final String DEFAULT_BASE_URL = DEFAULT_ROOT_URL + DEFAULT_SERVICE_PATH;

  /**
   * Constructor.
   *
   * <p>
   * Use {@link Builder} if you need to specify any of the optional parameters.
   * </p>
   *
   * @param transport HTTP transport, which should normally be:
   *        <ul>
   *        <li>Google App Engine:
   *        {@code com.google.api.client.extensions.appengine.http.UrlFetchTransport}</li>
   *        <li>Android: {@code newCompatibleTransport} from
   *        {@code com.google.api.client.extensions.android.http.AndroidHttp}</li>
   *        <li>Java: {@link com.google.api.client.googleapis.javanet.GoogleNetHttpTransport#newTrustedTransport()}
   *        </li>
   *        </ul>
   * @param jsonFactory JSON factory, which may be:
   *        <ul>
   *        <li>Jackson: {@code com.google.api.client.json.jackson2.JacksonFactory}</li>
   *        <li>Google GSON: {@code com.google.api.client.json.gson.GsonFactory}</li>
   *        <li>Android Honeycomb or higher:
   *        {@code com.google.api.client.extensions.android.json.AndroidJsonFactory}</li>
   *        </ul>
   * @param httpRequestInitializer HTTP request initializer or {@code null} for none
   * @since 1.7
   */
  public GamesManagement(com.google.api.client.http.HttpTransport transport, com.google.api.client.json.JsonFactory jsonFactory,
      com.google.api.client.http.HttpRequestInitializer httpRequestInitializer) {
    this(new Builder(transport, jsonFactory, httpRequestInitializer));
  }

  /**
   * @param builder builder
   */
  GamesManagement(Builder builder) {
    super(builder);
  }

  @Override
  protected void initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest<?> httpClientRequest) throws java.io.IOException {
    super.initialize(httpClientRequest);
  }

  /**
   * An accessor for creating requests from the Achievements collection.
   *
   * <p>The typical use is:</p>
   * <pre>
   *   {@code GamesManagement gamesManagement = new GamesManagement(...);}
   *   {@code GamesManagement.Achievements.List request = gamesManagement.achievements().list(parameters ...)}
   * </pre>
   *
   * @return the resource collection
   */
  public Achievements achievements() {
    return new Achievements();
  }

  /**
   * The "achievements" collection of methods.
   */
  public class Achievements {

    /**
     * Resets the achievement with the given ID for the currently authenticated player. This method is
     * only accessible to whitelisted tester accounts for your application.
     *
     * Create a request for the method "achievements.reset".
     *
     * This request holds the parameters needed by the the gamesManagement server.  After setting any
     * optional parameters, call the {@link Reset#execute()} method to invoke the remote operation.
     *
     * @param achievementId The ID of the achievement used by this method.
     * @return the request
     */
    public Reset reset(java.lang.String achievementId) throws java.io.IOException {
      Reset result = new Reset(achievementId);
      initialize(result);
      return result;
    }

    public class Reset extends GamesManagementRequest<com.google.api.services.gamesManagement.model.AchievementResetResponse> {

      private static final String REST_PATH = "achievements/{achievementId}/reset";

      /**
       * Resets the achievement with the given ID for the currently authenticated player. This method is
       * only accessible to whitelisted tester accounts for your application.
       *
       * Create a request for the method "achievements.reset".
       *
       * This request holds the parameters needed by the the gamesManagement server.  After setting any
       * optional parameters, call the {@link Reset#execute()} method to invoke the remote operation.
       * <p> {@link
       * Reset#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)} must
       * be called to initialize this instance immediately after invoking the constructor. </p>
       *
       * @param achievementId The ID of the achievement used by this method.
       * @since 1.13
       */
      protected Reset(java.lang.String achievementId) {
        super(GamesManagement.this, "POST", REST_PATH, null, com.google.api.services.gamesManagement.model.AchievementResetResponse.class);
        this.achievementId = com.google.api.client.util.Preconditions.checkNotNull(achievementId, "Required parameter achievementId must be specified.");
      }

      @Override
      public Reset setAlt(java.lang.String alt) {
        return (Reset) super.setAlt(alt);
      }

      @Override
      public Reset setFields(java.lang.String fields) {
        return (Reset) super.setFields(fields);
      }

      @Override
      public Reset setKey(java.lang.String key) {
        return (Reset) super.setKey(key);
      }

      @Override
      public Reset setOauthToken(java.lang.String oauthToken) {
        return (Reset) super.setOauthToken(oauthToken);
      }

      @Override
      public Reset setPrettyPrint(java.lang.Boolean prettyPrint) {
        return (Reset) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Reset setQuotaUser(java.lang.String quotaUser) {
        return (Reset) super.setQuotaUser(quotaUser);
      }

      @Override
      public Reset setUserIp(java.lang.String userIp) {
        return (Reset) super.setUserIp(userIp);
      }

      /** The ID of the achievement used by this method. */
      @com.google.api.client.util.Key
      private java.lang.String achievementId;

      /** The ID of the achievement used by this method.
       */
      public java.lang.String getAchievementId() {
        return achievementId;
      }

      /** The ID of the achievement used by this method. */
      public Reset setAchievementId(java.lang.String achievementId) {
        this.achievementId = achievementId;
        return this;
      }

      @Override
      public Reset set(String parameterName, Object value) {
        return (Reset) super.set(parameterName, value);
      }
    }
    /**
     * Resets all achievements for the currently authenticated player for your application. This method
     * is only accessible to whitelisted tester accounts for your application.
     *
     * Create a request for the method "achievements.resetAll".
     *
     * This request holds the parameters needed by the the gamesManagement server.  After setting any
     * optional parameters, call the {@link ResetAll#execute()} method to invoke the remote operation.
     *
     * @return the request
     */
    public ResetAll resetAll() throws java.io.IOException {
      ResetAll result = new ResetAll();
      initialize(result);
      return result;
    }

    public class ResetAll extends GamesManagementRequest<com.google.api.services.gamesManagement.model.AchievementResetAllResponse> {

      private static final String REST_PATH = "achievements/reset";

      /**
       * Resets all achievements for the currently authenticated player for your application. This
       * method is only accessible to whitelisted tester accounts for your application.
       *
       * Create a request for the method "achievements.resetAll".
       *
       * This request holds the parameters needed by the the gamesManagement server.  After setting any
       * optional parameters, call the {@link ResetAll#execute()} method to invoke the remote operation.
       * <p> {@link
       * ResetAll#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)}
       * must be called to initialize this instance immediately after invoking the constructor. </p>
       *
       * @since 1.13
       */
      protected ResetAll() {
        super(GamesManagement.this, "POST", REST_PATH, null, com.google.api.services.gamesManagement.model.AchievementResetAllResponse.class);
      }

      @Override
      public ResetAll setAlt(java.lang.String alt) {
        return (ResetAll) super.setAlt(alt);
      }

      @Override
      public ResetAll setFields(java.lang.String fields) {
        return (ResetAll) super.setFields(fields);
      }

      @Override
      public ResetAll setKey(java.lang.String key) {
        return (ResetAll) super.setKey(key);
      }

      @Override
      public ResetAll setOauthToken(java.lang.String oauthToken) {
        return (ResetAll) super.setOauthToken(oauthToken);
      }

      @Override
      public ResetAll setPrettyPrint(java.lang.Boolean prettyPrint) {
        return (ResetAll) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public ResetAll setQuotaUser(java.lang.String quotaUser) {
        return (ResetAll) super.setQuotaUser(quotaUser);
      }

      @Override
      public ResetAll setUserIp(java.lang.String userIp) {
        return (ResetAll) super.setUserIp(userIp);
      }

      @Override
      public ResetAll set(String parameterName, Object value) {
        return (ResetAll) super.set(parameterName, value);
      }
    }

  }

  /**
   * An accessor for creating requests from the Applications collection.
   *
   * <p>The typical use is:</p>
   * <pre>
   *   {@code GamesManagement gamesManagement = new GamesManagement(...);}
   *   {@code GamesManagement.Applications.List request = gamesManagement.applications().list(parameters ...)}
   * </pre>
   *
   * @return the resource collection
   */
  public Applications applications() {
    return new Applications();
  }

  /**
   * The "applications" collection of methods.
   */
  public class Applications {

    /**
     * Get the list of players hidden from the given application. This method is only available to user
     * accounts for your developer console.
     *
     * Create a request for the method "applications.listHidden".
     *
     * This request holds the parameters needed by the the gamesManagement server.  After setting any
     * optional parameters, call the {@link ListHidden#execute()} method to invoke the remote operation.
     *
     * @param applicationId The application being requested.
     * @return the request
     */
    public ListHidden listHidden(java.lang.String applicationId) throws java.io.IOException {
      ListHidden result = new ListHidden(applicationId);
      initialize(result);
      return result;
    }

    public class ListHidden extends GamesManagementRequest<com.google.api.services.gamesManagement.model.HiddenPlayerList> {

      private static final String REST_PATH = "applications/{applicationId}/players/hidden";

      /**
       * Get the list of players hidden from the given application. This method is only available to
       * user accounts for your developer console.
       *
       * Create a request for the method "applications.listHidden".
       *
       * This request holds the parameters needed by the the gamesManagement server.  After setting any
       * optional parameters, call the {@link ListHidden#execute()} method to invoke the remote
       * operation. <p> {@link
       * ListHidden#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)}
       * must be called to initialize this instance immediately after invoking the constructor. </p>
       *
       * @param applicationId The application being requested.
       * @since 1.13
       */
      protected ListHidden(java.lang.String applicationId) {
        super(GamesManagement.this, "GET", REST_PATH, null, com.google.api.services.gamesManagement.model.HiddenPlayerList.class);
        this.applicationId = com.google.api.client.util.Preconditions.checkNotNull(applicationId, "Required parameter applicationId must be specified.");
      }

      @Override
      public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
        return super.executeUsingHead();
      }

      @Override
      public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
        return super.buildHttpRequestUsingHead();
      }

      @Override
      public ListHidden setAlt(java.lang.String alt) {
        return (ListHidden) super.setAlt(alt);
      }

      @Override
      public ListHidden setFields(java.lang.String fields) {
        return (ListHidden) super.setFields(fields);
      }

      @Override
      public ListHidden setKey(java.lang.String key) {
        return (ListHidden) super.setKey(key);
      }

      @Override
      public ListHidden setOauthToken(java.lang.String oauthToken) {
        return (ListHidden) super.setOauthToken(oauthToken);
      }

      @Override
      public ListHidden setPrettyPrint(java.lang.Boolean prettyPrint) {
        return (ListHidden) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public ListHidden setQuotaUser(java.lang.String quotaUser) {
        return (ListHidden) super.setQuotaUser(quotaUser);
      }

      @Override
      public ListHidden setUserIp(java.lang.String userIp) {
        return (ListHidden) super.setUserIp(userIp);
      }

      /** The application being requested. */
      @com.google.api.client.util.Key
      private java.lang.String applicationId;

      /** The application being requested.
       */
      public java.lang.String getApplicationId() {
        return applicationId;
      }

      /** The application being requested. */
      public ListHidden setApplicationId(java.lang.String applicationId) {
        this.applicationId = applicationId;
        return this;
      }

      /** The token returned by the previous request. */
      @com.google.api.client.util.Key
      private java.lang.String pageToken;

      /** The token returned by the previous request.
       */
      public java.lang.String getPageToken() {
        return pageToken;
      }

      /** The token returned by the previous request. */
      public ListHidden setPageToken(java.lang.String pageToken) {
        this.pageToken = pageToken;
        return this;
      }

      /**
       * The maximum number of player resources to return in the response, used for paging. For any
       * response, the actual number of player resources returned may be less than the specified
       * maxResults.
       */
      @com.google.api.client.util.Key
      private java.lang.Integer maxResults;

      /** The maximum number of player resources to return in the response, used for paging. For any
     response, the actual number of player resources returned may be less than the specified maxResults.

     [minimum: 1] [maximum: 15]
       */
      public java.lang.Integer getMaxResults() {
        return maxResults;
      }

      /**
       * The maximum number of player resources to return in the response, used for paging. For any
       * response, the actual number of player resources returned may be less than the specified
       * maxResults.
       */
      public ListHidden setMaxResults(java.lang.Integer maxResults) {
        this.maxResults = maxResults;
        return this;
      }

      @Override
      public ListHidden set(String parameterName, Object value) {
        return (ListHidden) super.set(parameterName, value);
      }
    }

  }

  /**
   * An accessor for creating requests from the Players collection.
   *
   * <p>The typical use is:</p>
   * <pre>
   *   {@code GamesManagement gamesManagement = new GamesManagement(...);}
   *   {@code GamesManagement.Players.List request = gamesManagement.players().list(parameters ...)}
   * </pre>
   *
   * @return the resource collection
   */
  public Players players() {
    return new Players();
  }

  /**
   * The "players" collection of methods.
   */
  public class Players {

    /**
     * Hide the given player's leaderboard scores from the given application. This method is only
     * available to user accounts for your developer console.
     *
     * Create a request for the method "players.hide".
     *
     * This request holds the parameters needed by the the gamesManagement server.  After setting any
     * optional parameters, call the {@link Hide#execute()} method to invoke the remote operation.
     *
     * @param applicationId The application being requested.
     * @param playerId A player ID. A value of me may be used in place of the authenticated player's ID.
     * @return the request
     */
    public Hide hide(java.lang.String applicationId, java.lang.String playerId) throws java.io.IOException {
      Hide result = new Hide(applicationId, playerId);
      initialize(result);
      return result;
    }

    public class Hide extends GamesManagementRequest<Void> {

      private static final String REST_PATH = "applications/{applicationId}/players/hidden/{playerId}";

      /**
       * Hide the given player's leaderboard scores from the given application. This method is only
       * available to user accounts for your developer console.
       *
       * Create a request for the method "players.hide".
       *
       * This request holds the parameters needed by the the gamesManagement server.  After setting any
       * optional parameters, call the {@link Hide#execute()} method to invoke the remote operation. <p>
       * {@link Hide#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)}
       * must be called to initialize this instance immediately after invoking the constructor. </p>
       *
       * @param applicationId The application being requested.
       * @param playerId A player ID. A value of me may be used in place of the authenticated player's ID.
       * @since 1.13
       */
      protected Hide(java.lang.String applicationId, java.lang.String playerId) {
        super(GamesManagement.this, "POST", REST_PATH, null, Void.class);
        this.applicationId = com.google.api.client.util.Preconditions.checkNotNull(applicationId, "Required parameter applicationId must be specified.");
        this.playerId = com.google.api.client.util.Preconditions.checkNotNull(playerId, "Required parameter playerId must be specified.");
      }

      @Override
      public Hide setAlt(java.lang.String alt) {
        return (Hide) super.setAlt(alt);
      }

      @Override
      public Hide setFields(java.lang.String fields) {
        return (Hide) super.setFields(fields);
      }

      @Override
      public Hide setKey(java.lang.String key) {
        return (Hide) super.setKey(key);
      }

      @Override
      public Hide setOauthToken(java.lang.String oauthToken) {
        return (Hide) super.setOauthToken(oauthToken);
      }

      @Override
      public Hide setPrettyPrint(java.lang.Boolean prettyPrint) {
        return (Hide) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Hide setQuotaUser(java.lang.String quotaUser) {
        return (Hide) super.setQuotaUser(quotaUser);
      }

      @Override
      public Hide setUserIp(java.lang.String userIp) {
        return (Hide) super.setUserIp(userIp);
      }

      /** The application being requested. */
      @com.google.api.client.util.Key
      private java.lang.String applicationId;

      /** The application being requested.
       */
      public java.lang.String getApplicationId() {
        return applicationId;
      }

      /** The application being requested. */
      public Hide setApplicationId(java.lang.String applicationId) {
        this.applicationId = applicationId;
        return this;
      }

      /** A player ID. A value of me may be used in place of the authenticated player's ID. */
      @com.google.api.client.util.Key
      private java.lang.String playerId;

      /** A player ID. A value of me may be used in place of the authenticated player's ID.
       */
      public java.lang.String getPlayerId() {
        return playerId;
      }

      /** A player ID. A value of me may be used in place of the authenticated player's ID. */
      public Hide setPlayerId(java.lang.String playerId) {
        this.playerId = playerId;
        return this;
      }

      @Override
      public Hide set(String parameterName, Object value) {
        return (Hide) super.set(parameterName, value);
      }
    }
    /**
     * Unhide the given player's leaderboard scores from the given application. This method is only
     * available to user accounts for your developer console.
     *
     * Create a request for the method "players.unhide".
     *
     * This request holds the parameters needed by the the gamesManagement server.  After setting any
     * optional parameters, call the {@link Unhide#execute()} method to invoke the remote operation.
     *
     * @param applicationId The application being requested.
     * @param playerId A player ID. A value of me may be used in place of the authenticated player's ID.
     * @return the request
     */
    public Unhide unhide(java.lang.String applicationId, java.lang.String playerId) throws java.io.IOException {
      Unhide result = new Unhide(applicationId, playerId);
      initialize(result);
      return result;
    }

    public class Unhide extends GamesManagementRequest<Void> {

      private static final String REST_PATH = "applications/{applicationId}/players/hidden/{playerId}";

      /**
       * Unhide the given player's leaderboard scores from the given application. This method is only
       * available to user accounts for your developer console.
       *
       * Create a request for the method "players.unhide".
       *
       * This request holds the parameters needed by the the gamesManagement server.  After setting any
       * optional parameters, call the {@link Unhide#execute()} method to invoke the remote operation.
       * <p> {@link
       * Unhide#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)} must
       * be called to initialize this instance immediately after invoking the constructor. </p>
       *
       * @param applicationId The application being requested.
       * @param playerId A player ID. A value of me may be used in place of the authenticated player's ID.
       * @since 1.13
       */
      protected Unhide(java.lang.String applicationId, java.lang.String playerId) {
        super(GamesManagement.this, "DELETE", REST_PATH, null, Void.class);
        this.applicationId = com.google.api.client.util.Preconditions.checkNotNull(applicationId, "Required parameter applicationId must be specified.");
        this.playerId = com.google.api.client.util.Preconditions.checkNotNull(playerId, "Required parameter playerId must be specified.");
      }

      @Override
      public Unhide setAlt(java.lang.String alt) {
        return (Unhide) super.setAlt(alt);
      }

      @Override
      public Unhide setFields(java.lang.String fields) {
        return (Unhide) super.setFields(fields);
      }

      @Override
      public Unhide setKey(java.lang.String key) {
        return (Unhide) super.setKey(key);
      }

      @Override
      public Unhide setOauthToken(java.lang.String oauthToken) {
        return (Unhide) super.setOauthToken(oauthToken);
      }

      @Override
      public Unhide setPrettyPrint(java.lang.Boolean prettyPrint) {
        return (Unhide) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Unhide setQuotaUser(java.lang.String quotaUser) {
        return (Unhide) super.setQuotaUser(quotaUser);
      }

      @Override
      public Unhide setUserIp(java.lang.String userIp) {
        return (Unhide) super.setUserIp(userIp);
      }

      /** The application being requested. */
      @com.google.api.client.util.Key
      private java.lang.String applicationId;

      /** The application being requested.
       */
      public java.lang.String getApplicationId() {
        return applicationId;
      }

      /** The application being requested. */
      public Unhide setApplicationId(java.lang.String applicationId) {
        this.applicationId = applicationId;
        return this;
      }

      /** A player ID. A value of me may be used in place of the authenticated player's ID. */
      @com.google.api.client.util.Key
      private java.lang.String playerId;

      /** A player ID. A value of me may be used in place of the authenticated player's ID.
       */
      public java.lang.String getPlayerId() {
        return playerId;
      }

      /** A player ID. A value of me may be used in place of the authenticated player's ID. */
      public Unhide setPlayerId(java.lang.String playerId) {
        this.playerId = playerId;
        return this;
      }

      @Override
      public Unhide set(String parameterName, Object value) {
        return (Unhide) super.set(parameterName, value);
      }
    }

  }

  /**
   * An accessor for creating requests from the Rooms collection.
   *
   * <p>The typical use is:</p>
   * <pre>
   *   {@code GamesManagement gamesManagement = new GamesManagement(...);}
   *   {@code GamesManagement.Rooms.List request = gamesManagement.rooms().list(parameters ...)}
   * </pre>
   *
   * @return the resource collection
   */
  public Rooms rooms() {
    return new Rooms();
  }

  /**
   * The "rooms" collection of methods.
   */
  public class Rooms {

    /**
     * Reset all rooms for the currently authenticated player for your application. This method is only
     * accessible to whitelisted tester accounts for your application.
     *
     * Create a request for the method "rooms.reset".
     *
     * This request holds the parameters needed by the the gamesManagement server.  After setting any
     * optional parameters, call the {@link Reset#execute()} method to invoke the remote operation.
     *
     * @return the request
     */
    public Reset reset() throws java.io.IOException {
      Reset result = new Reset();
      initialize(result);
      return result;
    }

    public class Reset extends GamesManagementRequest<Void> {

      private static final String REST_PATH = "rooms/reset";

      /**
       * Reset all rooms for the currently authenticated player for your application. This method is
       * only accessible to whitelisted tester accounts for your application.
       *
       * Create a request for the method "rooms.reset".
       *
       * This request holds the parameters needed by the the gamesManagement server.  After setting any
       * optional parameters, call the {@link Reset#execute()} method to invoke the remote operation.
       * <p> {@link
       * Reset#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)} must
       * be called to initialize this instance immediately after invoking the constructor. </p>
       *
       * @since 1.13
       */
      protected Reset() {
        super(GamesManagement.this, "POST", REST_PATH, null, Void.class);
      }

      @Override
      public Reset setAlt(java.lang.String alt) {
        return (Reset) super.setAlt(alt);
      }

      @Override
      public Reset setFields(java.lang.String fields) {
        return (Reset) super.setFields(fields);
      }

      @Override
      public Reset setKey(java.lang.String key) {
        return (Reset) super.setKey(key);
      }

      @Override
      public Reset setOauthToken(java.lang.String oauthToken) {
        return (Reset) super.setOauthToken(oauthToken);
      }

      @Override
      public Reset setPrettyPrint(java.lang.Boolean prettyPrint) {
        return (Reset) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Reset setQuotaUser(java.lang.String quotaUser) {
        return (Reset) super.setQuotaUser(quotaUser);
      }

      @Override
      public Reset setUserIp(java.lang.String userIp) {
        return (Reset) super.setUserIp(userIp);
      }

      @Override
      public Reset set(String parameterName, Object value) {
        return (Reset) super.set(parameterName, value);
      }
    }

  }

  /**
   * An accessor for creating requests from the Scores collection.
   *
   * <p>The typical use is:</p>
   * <pre>
   *   {@code GamesManagement gamesManagement = new GamesManagement(...);}
   *   {@code GamesManagement.Scores.List request = gamesManagement.scores().list(parameters ...)}
   * </pre>
   *
   * @return the resource collection
   */
  public Scores scores() {
    return new Scores();
  }

  /**
   * The "scores" collection of methods.
   */
  public class Scores {

    /**
     * Reset scores for the specified leaderboard for the currently authenticated player. This method is
     * only accessible to whitelisted tester accounts for your application.
     *
     * Create a request for the method "scores.reset".
     *
     * This request holds the parameters needed by the the gamesManagement server.  After setting any
     * optional parameters, call the {@link Reset#execute()} method to invoke the remote operation.
     *
     * @param leaderboardId The ID of the leaderboard.
     * @return the request
     */
    public Reset reset(java.lang.String leaderboardId) throws java.io.IOException {
      Reset result = new Reset(leaderboardId);
      initialize(result);
      return result;
    }

    public class Reset extends GamesManagementRequest<com.google.api.services.gamesManagement.model.PlayerScoreResetResponse> {

      private static final String REST_PATH = "leaderboards/{leaderboardId}/scores/reset";

      /**
       * Reset scores for the specified leaderboard for the currently authenticated player. This method
       * is only accessible to whitelisted tester accounts for your application.
       *
       * Create a request for the method "scores.reset".
       *
       * This request holds the parameters needed by the the gamesManagement server.  After setting any
       * optional parameters, call the {@link Reset#execute()} method to invoke the remote operation.
       * <p> {@link
       * Reset#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)} must
       * be called to initialize this instance immediately after invoking the constructor. </p>
       *
       * @param leaderboardId The ID of the leaderboard.
       * @since 1.13
       */
      protected Reset(java.lang.String leaderboardId) {
        super(GamesManagement.this, "POST", REST_PATH, null, com.google.api.services.gamesManagement.model.PlayerScoreResetResponse.class);
        this.leaderboardId = com.google.api.client.util.Preconditions.checkNotNull(leaderboardId, "Required parameter leaderboardId must be specified.");
      }

      @Override
      public Reset setAlt(java.lang.String alt) {
        return (Reset) super.setAlt(alt);
      }

      @Override
      public Reset setFields(java.lang.String fields) {
        return (Reset) super.setFields(fields);
      }

      @Override
      public Reset setKey(java.lang.String key) {
        return (Reset) super.setKey(key);
      }

      @Override
      public Reset setOauthToken(java.lang.String oauthToken) {
        return (Reset) super.setOauthToken(oauthToken);
      }

      @Override
      public Reset setPrettyPrint(java.lang.Boolean prettyPrint) {
        return (Reset) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Reset setQuotaUser(java.lang.String quotaUser) {
        return (Reset) super.setQuotaUser(quotaUser);
      }

      @Override
      public Reset setUserIp(java.lang.String userIp) {
        return (Reset) super.setUserIp(userIp);
      }

      /** The ID of the leaderboard. */
      @com.google.api.client.util.Key
      private java.lang.String leaderboardId;

      /** The ID of the leaderboard.
       */
      public java.lang.String getLeaderboardId() {
        return leaderboardId;
      }

      /** The ID of the leaderboard. */
      public Reset setLeaderboardId(java.lang.String leaderboardId) {
        this.leaderboardId = leaderboardId;
        return this;
      }

      @Override
      public Reset set(String parameterName, Object value) {
        return (Reset) super.set(parameterName, value);
      }
    }

  }

  /**
   * Builder for {@link GamesManagement}.
   *
   * <p>
   * Implementation is not thread-safe.
   * </p>
   *
   * @since 1.3.0
   */
  public static final class Builder extends com.google.api.client.googleapis.services.json.AbstractGoogleJsonClient.Builder {

    /**
     * Returns an instance of a new builder.
     *
     * @param transport HTTP transport, which should normally be:
     *        <ul>
     *        <li>Google App Engine:
     *        {@code com.google.api.client.extensions.appengine.http.UrlFetchTransport}</li>
     *        <li>Android: {@code newCompatibleTransport} from
     *        {@code com.google.api.client.extensions.android.http.AndroidHttp}</li>
     *        <li>Java: {@link com.google.api.client.googleapis.javanet.GoogleNetHttpTransport#newTrustedTransport()}
     *        </li>
     *        </ul>
     * @param jsonFactory JSON factory, which may be:
     *        <ul>
     *        <li>Jackson: {@code com.google.api.client.json.jackson2.JacksonFactory}</li>
     *        <li>Google GSON: {@code com.google.api.client.json.gson.GsonFactory}</li>
     *        <li>Android Honeycomb or higher:
     *        {@code com.google.api.client.extensions.android.json.AndroidJsonFactory}</li>
     *        </ul>
     * @param httpRequestInitializer HTTP request initializer or {@code null} for none
     * @since 1.7
     */
    public Builder(com.google.api.client.http.HttpTransport transport, com.google.api.client.json.JsonFactory jsonFactory,
        com.google.api.client.http.HttpRequestInitializer httpRequestInitializer) {
      super(
          transport,
          jsonFactory,
          DEFAULT_ROOT_URL,
          DEFAULT_SERVICE_PATH,
          httpRequestInitializer,
          false);
    }

    /** Builds a new instance of {@link GamesManagement}. */
    @Override
    public GamesManagement build() {
      return new GamesManagement(this);
    }

    @Override
    public Builder setRootUrl(String rootUrl) {
      return (Builder) super.setRootUrl(rootUrl);
    }

    @Override
    public Builder setServicePath(String servicePath) {
      return (Builder) super.setServicePath(servicePath);
    }

    @Override
    public Builder setHttpRequestInitializer(com.google.api.client.http.HttpRequestInitializer httpRequestInitializer) {
      return (Builder) super.setHttpRequestInitializer(httpRequestInitializer);
    }

    @Override
    public Builder setApplicationName(String applicationName) {
      return (Builder) super.setApplicationName(applicationName);
    }

    @Override
    public Builder setSuppressPatternChecks(boolean suppressPatternChecks) {
      return (Builder) super.setSuppressPatternChecks(suppressPatternChecks);
    }

    @Override
    public Builder setSuppressRequiredParameterChecks(boolean suppressRequiredParameterChecks) {
      return (Builder) super.setSuppressRequiredParameterChecks(suppressRequiredParameterChecks);
    }

    @Override
    public Builder setSuppressAllChecks(boolean suppressAllChecks) {
      return (Builder) super.setSuppressAllChecks(suppressAllChecks);
    }

    /**
     * Set the {@link GamesManagementRequestInitializer}.
     *
     * @since 1.12
     */
    public Builder setGamesManagementRequestInitializer(
        GamesManagementRequestInitializer gamesmanagementRequestInitializer) {
      return (Builder) super.setGoogleClientRequestInitializer(gamesmanagementRequestInitializer);
    }

    @Override
    public Builder setGoogleClientRequestInitializer(
        com.google.api.client.googleapis.services.GoogleClientRequestInitializer googleClientRequestInitializer) {
      return (Builder) super.setGoogleClientRequestInitializer(googleClientRequestInitializer);
    }
  }
}
